Hi all! I made this package for my own personal use, so I don't take any responisbility for any unwanted consequences. You it at you own risk please!
If you happen to use it for making money, we shall go splitzies on the casharino you make! ^_^
That is all. Thank you and have a nice day! :)